@@ -251,6 +251,15 @@ extern "C"
      */
     LIBFAUST_API const char** getCDSPFactoryIncludePathnames(llvm_dsp_factory* factory);
     
+    /**
+     * Get warning messages list for a given compilation as a null-terminated array.
+     *
+     * @param factory - the DSP factory.
+     *
+     * @return the warning messages list (the array and it's content has to be deleted by the caller using freeCMemory).
+     */
+    LIBFAUST_API const char** getCWarningMessages(llvm_dsp_factory* factory);
+
     /**
      * Delete all Faust DSP factories kept in the library cache. Beware: all kept factory pointers (in local variables...) thus become invalid.
      */                                 
@@ -263,6 +272,10 @@ extern "C"
      */    
     LIBFAUST_API const char** getAllCDSPFactories();
     
+    
+    /* Static tables initialization */
+    LIBFAUST_API void classCInit(llvm_dsp_factory* factory, int sample_rate);
+    
     /**
      * Start multi-thread access mode (since by default the library is not 'multi-thread' safe).
      * 
